var union_ogre_bites_1_1_event =
[
    [ "type", "union_ogre_bites_1_1_event.html#a31b7daeb33a3e12c5e6a6a966e72c703", null ],
    [ "key", "union_ogre_bites_1_1_event.html#a4b557f486480f2ff19f9966000108556", null ],
    [ "button", "union_ogre_bites_1_1_event.html#a7e15fa094ce1387f9597c1b21d6f6955", null ],
    [ "wheel", "union_ogre_bites_1_1_event.html#a722998a9ff7c2401bd224f36f70da198", null ],
    [ "motion", "union_ogre_bites_1_1_event.html#a754b548f93280e2a2aa9f18ff8da898a", null ],
    [ "tfinger", "union_ogre_bites_1_1_event.html#adb1cee81610d1700eef37fa281ea14e3", null ],
    [ "text", "union_ogre_bites_1_1_event.html#afe98c3cbfefeec08de511d16d5dd624e", null ],
    [ "axis", "union_ogre_bites_1_1_event.html#a4580f722360bd8b75b1c6ddffbcbeada", null ],
    [ "cbutton", "union_ogre_bites_1_1_event.html#ac645626194defe49c109be496494deae", null ],
    [ "hat", "union_ogre_bites_1_1_event.html#a331469d3f5cbdec546304908c29e1749", null ]
];